@@ -43,9 +43,8 @@ from pytket.passes import (  # type: ignore
     DecomposeBoxes,
     FullPeepholeOptimise,
     RebaseCustom,
-    RebaseIBM,
     SequencePass,
-    SynthesiseIBM,
+    SynthesiseTket,
 )
 from pytket.pauli import Pauli, QubitPauliString  # type: ignore
 from pytket.predicates import (  # type: ignore
@@ -116,6 +115,8 @@ class _AerBaseBackend(Backend):
             for gate_str in self._backend.configuration().basis_gates
             if gate_str in _gate_str_2_optype
         }
+        # special case mapping TK1 to U
+        gate_set.add(OpType.TK1)
         if not gate_set >= _required_gates:
             raise NotImplementedError(
                 f"Gate set {gate_set} missing at least one of {_required_gates}"
@@ -156,19 +157,16 @@ class _AerBaseBackend(Backend):
     def process_circuits(
         self,
         circuits: Sequence[Circuit],
-        n_shots: Optional[Union[int, Sequence[int]]] = None,
+        n_shots: Union[None, int, Sequence[Optional[int]]] = None,
         valid_check: bool = True,
         **kwargs: KwargTypes,
     ) -> List[ResultHandle]:
         circuits = list(circuits)
-        n_shots_list: List[Optional[int]] = []
-        if hasattr(n_shots, "__iter__"):
-            n_shots_list = cast(List[Optional[int]], n_shots)
-            if len(n_shots_list) != len(circuits):
-                raise ValueError("The length of n_shots and circuits must match")
-        else:
-            # convert n_shots to a list
-            n_shots_list = [cast(int, n_shots)] * len(circuits)
+        n_shots_list = Backend._get_n_shots_as_list(
+            n_shots,
+            len(circuits),
+            optional=True,
+        )
 
         if valid_check:
             self._check_all_circuits(circuits)
@@ -330,16 +328,16 @@ class _AerStateBaseBackend(_AerBaseBackend):
     def default_compilation_pass(self, optimisation_level: int = 1) -> BasePass:
         assert optimisation_level in range(3)
         if optimisation_level == 0:
-            return SequencePass([DecomposeBoxes(), RebaseIBM()])
+            return SequencePass([DecomposeBoxes(), self._rebase_pass])
         elif optimisation_level == 1:
-            return SequencePass([DecomposeBoxes(), SynthesiseIBM()])
+            return SequencePass([DecomposeBoxes(), SynthesiseTket()])
         else:
             return SequencePass([DecomposeBoxes(), FullPeepholeOptimise()])
 
     def process_circuits(
         self,
         circuits: Sequence[Circuit],
-        n_shots: Optional[Union[int, Sequence[int]]] = None,
+        n_shots: Union[None, int, Sequence[Optional[int]]] = None,
         valid_check: bool = True,
         **kwargs: KwargTypes,
     ) -> List[ResultHandle]:
@@ -488,7 +486,7 @@ class AerBackend(_AerBaseBackend):
         if optimisation_level == 0:
             passlist.append(self._rebase_pass)
         elif optimisation_level == 1:
-            passlist.append(SynthesiseIBM())
+            passlist.append(SynthesiseTket())
         else:
             passlist.append(FullPeepholeOptimise())
         arch = self._backend_info.architecture
@@ -510,15 +508,15 @@ class AerBackend(_AerBaseBackend):
             if optimisation_level == 0:
                 passlist.append(self._rebase_pass)
             elif optimisation_level == 1:
-                passlist.append(SynthesiseIBM())
+                passlist.append(SynthesiseTket())
             else:
-                passlist.extend([CliffordSimp(False), SynthesiseIBM()])
+                passlist.extend([CliffordSimp(False), SynthesiseTket()])
         return SequencePass(passlist)
 
     def process_circuits(
         self,
         circuits: Sequence[Circuit],
-        n_shots: Optional[Union[int, Sequence[int]]] = None,
+        n_shots: Union[None, int, Sequence[Optional[int]]] = None,
         valid_check: bool = True,
         **kwargs: KwargTypes,
     ) -> List[ResultHandle]:
@@ -526,16 +524,12 @@ class AerBackend(_AerBaseBackend):
         See :py:meth:`pytket.backends.Backend.process_circuits`.
         Supported kwargs: `seed`.
         """
-        if hasattr(n_shots, "__iter__"):
-            n_shots_list = cast(Sequence[Optional[int]], n_shots)
-            if any(map(lambda n: n is None or n < 1, n_shots_list)):
-                raise ValueError(
-                    "n_shots values are required for all circuits for this backend"
-                )
-        else:
-            n_shots_int = cast(Optional[int], n_shots)
-            if n_shots_int is None or n_shots_int < 1:
-                raise ValueError("Parameter n_shots is required for this backend.")
+        # discard result but useful to validate n_shots
+        Backend._get_n_shots_as_list(
+            n_shots,
+            len(circuits),
+            optional=False,
+        )
         return super().process_circuits(circuits, n_shots, valid_check, **kwargs)
 
     def get_pauli_expectation_value(
